@@ -47,8 +47,9 @@ type spxObj struct {
 }
 
 type gmxProject struct {
-	gameClass  string            // <gmtype>.gmx
-	game       gogen.Ref         // Game (project base class)
+	gameClass  string    // <gmtype>.gmx
+	game       gogen.Ref // Game (project base class)
+	spfeats    spriteFeat
 	sprite     map[string]spxObj // .spx => Sprite
 	sptypes    []string          // <sptype>.spx
 	scheds     []string
@@ -62,6 +63,43 @@ type gmxProject struct {
 	hasMain_   bool
 }
 
+type spriteFeat uint
+
+const (
+	spriteClassfname spriteFeat = 1 << iota
+	spriteClassclone
+)
+
+func spriteFeatures(game gogen.Ref) (feats spriteFeat) {
+	if mainFn := findMethod(game, "Main"); mainFn != nil {
+		sig := mainFn.Type().(*types.Signature)
+		if t, ok := gogen.CheckSigFuncEx(sig); ok {
+			if t, ok := t.(*gogen.TyTemplateRecvMethod); ok {
+				sig = t.Func.Type().(*types.Signature)
+			}
+		}
+		if sig.Variadic() {
+			in := sig.Params()
+			last := in.At(in.Len() - 1)
+			elt := last.Type().(*types.Slice).Elem()
+			if tn, ok := elt.(*types.Named); ok {
+				elt = tn.Underlying()
+			}
+			if intf, ok := elt.(*types.Interface); ok {
+				for i, n := 0, intf.NumMethods(); i < n; i++ {
+					switch intf.Method(i).Name() {
+					case "Classfname":
+						feats |= spriteClassfname
+					case "Classclone":
+						feats |= spriteClassclone
+					}
+				}
+			}
+		}
+	}
+	return
+}
+
 func (p *gmxProject) hasMain() bool {
 	if !p.hasMain_ {
 		imps := p.pkgImps
@@ -165,6 +203,7 @@ func loadClass(ctx *pkgCtx, pkg *gogen.Package, file string, f *ast.File, conf *
 		spx := p.pkgImps[0]
 		if gt.Class != "" {
 			p.game, p.gameIsPtr = spxRef(spx, gt.Class)
+			p.spfeats = spriteFeatures(p.game)
 		}
 		p.sprite = make(map[string]spxObj)
 		for _, v := range gt.Works {
@@ -460,6 +499,40 @@ func astFnClassfname(c *gmxClass) *ast.FuncDecl {
 	}
 }
 
+func astFnClassclone() *ast.FuncDecl {
+	ret := &ast.Ident{Name: "_gop_ret"}
+	return &ast.FuncDecl{
+		Name: &ast.Ident{
+			Name: "Classclone",
+		},
+		Type: &ast.FuncType{
+			Params: &ast.FieldList{},
+			Results: &ast.FieldList{
+				List: []*ast.Field{
+					{Type: &ast.Ident{Name: "any"}},
+				},
+			},
+		},
+		Body: &ast.BlockStmt{
+			List: []ast.Stmt{
+				&ast.AssignStmt{
+					Lhs: []ast.Expr{ret},
+					Tok: token.DEFINE,
+					Rhs: []ast.Expr{
+						&ast.StarExpr{X: &ast.Ident{Name: "this"}},
+					},
+				},
+				&ast.ReturnStmt{
+					Results: []ast.Expr{
+						&ast.UnaryExpr{Op: token.AND, X: ret},
+					},
+				},
+			},
+		},
+		Shadow: true,
+	}
+}
+
 func astEmptyEntrypoint(f *ast.File) {
 	var entry = getEntrypoint(f)
 	var hasEntry bool
