@@ -57,9 +57,6 @@ type MyGame struct {
 	*spx.MyGame
 }
 
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func (this *MyGame) Main() {
@@ -142,9 +139,6 @@ func (this *Kai) onMsg(msg string) {
 		this.Say("Hi")
 	}
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -199,9 +193,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -234,9 +225,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -270,9 +258,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -314,9 +299,6 @@ func (this *index) MainEntry() {
 func (this *index) Main() {
 	spx.Gopt_MyGame_Main(this)
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -372,9 +354,6 @@ func (this *bar) onInit() {
 	this.Say("Where do you come from?", 2)
 	this.Broadcast__0("msg2")
 }
-func (this *bar) Classfname() string {
-	return "bar"
-}
 func (this *bar) Main() {
 }
 func main() {
@@ -434,9 +413,6 @@ func (this *Kai) onInit() {
 func (this *Kai) onCloned() {
 	this.Say("Hi")
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -485,9 +461,6 @@ func (this *index) Main() {
 func (this *Kai) Main() {
 	fmt.Println("Hi")
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func main() {
 	new(index).Main()
 }
@@ -533,6 +506,10 @@ func (this *Kai) Main(_gop_arg0 string) {
 func (this *Kai) Classfname() string {
 	return "Kai"
 }
+func (this *Kai) Classclone() interface{} {
+	_gop_ret := *this
+	return &_gop_ret
+}
 func main() {
 	new(Game).Main()
 }
@@ -572,6 +549,10 @@ func (this *Game) Main() {
 func (this *Kai) Classfname() string {
 	return "Kai"
 }
+func (this *Kai) Classclone() interface{} {
+	_gop_ret := *this
+	return &_gop_ret
+}
 func (this *Kai) Main(_gop_arg0 string) {
 	this.Sprite.Main(_gop_arg0)
 }
@@ -610,9 +591,6 @@ func (this *Game) Main() {
 }
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -650,9 +628,6 @@ func (this *Game) Main() {
 }
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -684,14 +659,8 @@ type Kai struct {
 func (this *Dog) Main() {
 	fmt.Println("Hi, Sprite")
 }
-func (this *Dog) Classfname() string {
-	return "Dog"
-}
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 `, "Dog_t3spx.gox", "Kai.t3spx2")
@@ -721,9 +690,6 @@ func (this *Game) MainEntry() {
 func (this *Game) Main() {
 	(*spx2.Game).Main(&this.Game)
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -753,9 +719,6 @@ func (this *Game) MainEntry() {
 func (this *Game) Main() {
 	(*spx2.Game).Main(&this.Game)
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -803,9 +766,6 @@ func (this *Kai) Main() {
 }
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func main() {
 	new(Game).Main()
 }
@@ -852,9 +812,6 @@ func (this *Kai) onMsg(msg string) {
 		this.Say("Hi")
 	}
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -929,9 +886,6 @@ func (this *Kai) onInit() {
 func (this *Kai) onCloned() {
 	this.Say("Hi")
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -974,9 +928,6 @@ func (this *Game) Main() {
 }
 func (this *Kai) onMsg(msg string) {
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1016,9 +967,6 @@ func (this *Game) Main() {
 func (this *Kai) onMsg(msg string) {
 	this.Position().Add__0(100, 200)
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1083,9 +1031,6 @@ func (this *Kai) onMsg(msg string) {
 	fmt.Println(this.Vector().X)
 	fmt.Println(this.Vector().Self().Self())
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func (this *Kai) Main() {
 }
 func main() {
@@ -1197,9 +1142,6 @@ func (this *Kai) Main() {
 	spx.Gopt_Sprite_OnKey2(this, "hello", func(key string) {
 	})
 }
-func (this *Kai) Classfname() string {
-	return "Kai"
-}
 func main() {
 	new(Game).Main()
 }
@@ -1239,9 +1181,6 @@ func (this *caseFoo) Main() {
 		t.Fatal("failed")
 	})
 }
-func (this *caseFoo) Classfname() string {
-	return "Foo"
-}
 func TestFoo(t *testing.T) {
 	test.Gopt_Case_TestMain(new(caseFoo), t)
 }
@@ -1270,9 +1209,6 @@ type case_foo struct {
 func (this *case_foo) Main() {
 	this.T().Log("Hi")
 }
-func (this *case_foo) Classfname() string {
-	return "foo"
-}
 func Test_foo(t *testing.T) {
 	test.Gopt_Case_TestMain(new(case_foo), t)
 }
