@@ -18,58 +18,30 @@ package cl_test
 
 import (
 	"fmt"
-	"os"
 	"path/filepath"
 	"runtime"
 	"testing"
 
-	"github.com/goplus/gop/ast"
-	"github.com/goplus/gop/cl"
-	"github.com/goplus/gop/parser"
-	"github.com/goplus/gop/parser/fsx/memfs"
-	"github.com/goplus/gop/scanner"
+	"github.com/goplus/gop/cl/cltest"
 )
 
 func codeErrorTest(t *testing.T, msg, src string) {
-	codeErrorTestEx(t, "main", "bar.gop", msg, src)
+	cltest.ErrorEx(t, "main", "bar.gop", msg, src)
 }
 
 func codeErrorTestEx(t *testing.T, pkgname, filename, msg, src string) {
-	fs := memfs.SingleFile("/foo", filename, src)
-	pkgs, err := parser.ParseFSDir(gblFset, fs, "/foo", parser.Config{})
-	if err != nil {
-		scanner.PrintError(os.Stderr, err)
-		t.Fatal("parser.ParseFSDir failed")
-	}
-	conf := *gblConf
-	conf.NoFileLine = false
-	conf.RelativeBase = "/foo"
-	bar := pkgs[pkgname]
-	_, err = cl.NewPackage("", bar, &conf)
-	if err == nil {
-		t.Fatal("no error?")
-	}
-	if ret := err.Error(); ret != msg {
-		t.Fatalf("\nError: \"%s\"\nExpected: \"%s\"\n", ret, msg)
-	}
+	cltest.ErrorEx(t, pkgname, filename, msg, src)
 }
 
 func codeErrorTestAst(t *testing.T, pkgname, filename, msg, src string) {
-	f, _ := parser.ParseFile(gblFset, filename, src, parser.AllErrors)
-	pkg := &ast.Package{
-		Name:  pkgname,
-		Files: map[string]*ast.File{filename: f},
-	}
-	conf := *gblConf
-	conf.NoFileLine = false
-	conf.RelativeBase = "/foo"
-	_, err := cl.NewPackage("", pkg, &conf)
-	if err == nil {
-		t.Fatal("no error?")
-	}
-	if ret := err.Error(); ret != msg {
-		t.Fatalf("\nError: \"%s\"\nExpected: \"%s\"\n", ret, msg)
-	}
+	cltest.ErrorAst(t, pkgname, filename, msg, src)
+}
+
+func TestErrSendStmt(t *testing.T) {
+	codeErrorTest(t, `bar.gop:3:8: can't send multiple values to a channel`, `
+	var a chan int
+	a <- 1, 2
+`)
 }
 
 func TestErrVargCommand(t *testing.T) {
@@ -631,6 +603,12 @@ bar.gop:3:27: cannot use "Go" + "+" (type untyped string) as type int in map val
 		`
 a := map[string]int{1+2: 2}
 b := map[string]int{"Hi": "Go" + "+"}
+`)
+	codeErrorTest(t, `bar.gop:2:13: invalid map literal`, `
+var v any = {1:2,1}
+`)
+	codeErrorTest(t, `bar.gop:2:21: invalid map literal`, `
+var v map[int]int = {1:2,1}
 `)
 }
 
@@ -1049,3 +1027,87 @@ type
 a := 1
 `)
 }
+
+func TestCompileExprError(t *testing.T) {
+	codeErrorTestAst(t, "main", "bar.go", `bar.go:5:1: compileExpr failed: unknown - *ast.BadExpr`, `
+func Foo(){}
+func _() {
+	Foo(
+}
+`)
+	codeErrorTestAst(t, "main", "bar.go", `bar.go:3:2: compileExprLHS failed: unknown - *ast.StructType`, `
+func _() {
+	struct() = nil
+}
+`)
+}
+
+func TestOverloadFuncDecl(t *testing.T) {
+	codeErrorTest(t, "bar.gop:3:2: invalid func (foo).mulInt", `
+func mul = (
+	(foo).mulInt
+)
+`)
+	codeErrorTest(t, "bar.gop:2:7: invalid recv type *foo", `
+func (*foo).mul = (
+	(foo).mulInt
+)
+`)
+	codeErrorTest(t, "bar.gop:3:2: invalid recv type (foo2)", `
+func (foo).mul = (
+	(foo2).mulInt
+)
+`)
+	codeErrorTest(t, "bar.gop:3:2: invalid method mulInt", `
+func (foo).mul = (
+	mulInt
+)
+`)
+	codeErrorTest(t, "bar.gop:3:2: invalid recv type (**foo)", `
+func (foo).mul = (
+	(**foo).mulInt
+)
+`)
+	codeErrorTest(t, `bar.gop:3:9: unknown func ("ok")`, `
+func mul = (
+	println("ok")
+)
+`)
+	codeErrorTest(t, "bar.gop:3:2: invalid method func(){}", `
+func (foo).mul = (
+	func(){}
+)
+`)
+	codeErrorTest(t, "bar.gop:2:12: invalid overload operator ++", `
+func (foo).++ = (
+	mulInt
+)
+`)
+}
+
+func TestCompositeLitError(t *testing.T) {
+	codeErrorTest(t, `bar.gop:2:22: cannot use 3.14 (type untyped float) as type int in slice literal`, `
+var a [][]int = {[10,3.14,200],[100,200]}
+echo a
+`)
+	codeErrorTest(t, `bar.gop:2:17: cannot use lambda literal as type int in assignment`, `
+var a []int = {(x => x)}
+echo a
+`)
+	codeErrorTest(t, `bar.gop:2:35: cannot use x (type int) as type string in return argument`, `
+var a []func(int) string = {(x => x)}
+echo a
+`)
+	codeErrorTest(t, `bar.gop:2:27: cannot use lambda literal as type int in assignment to "A"`, `
+var a map[any]int = {"A": x => x}
+`)
+	codeErrorTest(t, `bar.gop:2:45: cannot use x (type int) as type string in return argument`, `
+var a map[any]func(int) string = {"A": x => x}
+`)
+	codeErrorTest(t, `bar.gop:2:24: cannot use lambda literal as type int in field value`, `
+var a = struct{v int}{(x => x)}
+`)
+	codeErrorTest(t, `bar.gop:2:27: cannot use lambda literal as type int in field value to v`, `
+var a = struct{v int}{v: (x => x)}
+`)
+}
