@@ -38,7 +38,13 @@ func (p *Sprite) Name() string {
 	return "sprite"
 }
 
-func (p *Sprite) initSprite() {}
+func (p *Sprite) Main(name string) {}
 
-func Gopt_Game_Main(game interface{ initGame() }, workers ...interface{ initSprite() }) {
+type iHandler interface {
+	Main(name string)
+	Classfname() string
+	Classclone() any
+}
+
+func Gopt_Game_Main(game interface{ initGame() }, workers ...iHandler) {
 }
