@@ -23,6 +23,7 @@ import (
 	"go/scanner"
 
 	"github.com/goplus/gop/ast"
+	"github.com/goplus/gop/parser/iox"
 	"github.com/goplus/gop/token"
 )
 
@@ -77,13 +78,13 @@ const (
 // errors were found, the result is a partial AST (with ast.Bad* nodes
 // representing the fragments of erroneous source code). Multiple errors
 // are returned via a scanner.ErrorList which is sorted by source position.
-func parseFile(fset *token.FileSet, filename string, src interface{}, mode Mode) (f *ast.File, err error) {
+func parseFile(fset *token.FileSet, filename string, src any, mode Mode) (f *ast.File, err error) {
 	if fset == nil {
 		panic("parser.ParseFile: no token.FileSet provided (fset == nil)")
 	}
 
 	// get source
-	text, err := readSourceLocal(filename, src)
+	text, err := iox.ReadSourceLocal(filename, src)
 	if err != nil {
 		return
 	}
@@ -133,7 +134,7 @@ func parseFile(fset *token.FileSet, filename string, src interface{}, mode Mode)
 // are returned via a scanner.ErrorList which is sorted by source position.
 func ParseExprFrom(fset *token.FileSet, filename string, src any, mode Mode) (expr ast.Expr, err error) {
 	// get source
-	text, err := readSourceLocal(filename, src)
+	text, err := iox.ReadSourceLocal(filename, src)
 	if err != nil {
 		return
 	}
